@@ -28,11 +28,10 @@
 #include <stdio.h>
 #include <ctype.h>
 #include <string.h>
+#include <glib/gi18n.h>
 #include <gtk/gtk.h>
 
 #include <libgnome/gnome-macros.h>
-#include <libgnome/gnome-i18n.h>
-#include "gnome-desktop-i18n.h"
 
 #include <libgnomeui/gnome-uidefs.h>
 #include <libgnomeui/gnome-icon-entry.h>
@@ -383,6 +382,8 @@ make_easy_page (GnomeDItemEdit *dee)
 	dee->_priv->exec_label = label;
 
 	entry = gnome_file_entry_new ("command", _("Browse"));
+	g_object_set (G_OBJECT (entry), "use-filechooser", TRUE, NULL);
+
 	gtk_label_set_mnemonic_widget (GTK_LABEL(label), gnome_file_entry_gnome_entry (GNOME_FILE_ENTRY (entry)));
 	table_attach_entry (GTK_TABLE (table), entry, 1, 2, 3, 4);
  
@@ -730,7 +731,7 @@ make_advanced_page (GnomeDItemEdit *dee)
 	gtk_label_set_mnemonic_widget (GTK_LABEL(label),
 	                               dee->_priv->translations);
 	gtk_scrolled_window_set_shadow_type (GTK_SCROLLED_WINDOW (box),
-					     GTK_SHADOW_NONE);
+					     GTK_SHADOW_IN);
 	gtk_scrolled_window_set_policy (GTK_SCROLLED_WINDOW (box),
 					GTK_POLICY_AUTOMATIC,
 					GTK_POLICY_AUTOMATIC);
